# CONTRIBUTIONS and CODE REVIEWS

We love contributions from the community. Please send pull requests and raise
issues! All code submissions require review. We use GitHub pull requests for
this purpose.

## COPYRIGHTS and LICENSE

Torii is licensed under the [BSD-2-Clause], the full text of which can be found in the [`LICENSE`] file in the root of this repository.

All authors retain copyright ownership of their contributions.

Authors should note that all contributions are licensed under the [BSD-2-Clause].

## CONTRIBUTORS

The complete list of contributors is contained within the git repository.
Tools such as the git log command can be used to see all contributions and
contributors.

## Use of Generative AI

This project explicitly does not allow any contributions that were generated in whole or in-part by large language models (LLMs), chatbots, or image generation systems. This ban includes tools, including but not limited to Copilot, ChatGPT, Claude, DeepSeek, Stable Diffusion, DALL-E, Midjourney, or Devin AI.

This policy covers all parts of the project, including, but not limited to code, documentation, issues, artworks, comments, discussions, pull requests, and any other contributions to Torii, without exception.

> [!NOTE]
> It is also recommended to avoid any and all AI tools when asking questions about Torii,
> prefer the documentation when available, as well as things such as the discussion forum, or IRC channel.
> These tools often fabricate plausible sounding information that is entirely incorrect, or often subtly
> incorrect and pass it off with confidence, thus misleading.

[BSD-2-Clause]: https://spdx.org/licenses/BSD-2-Clause.html
[`LICENSE`]: ./LICENSE
